[][src]Struct hogwild::Hogwild

pub struct Hogwild<T>(_);

Hogwild for arbitrary data types.

Hogwild subverts Rust's type system by allowing concurrent modification of values. This should only be used for data types that cannot end up in an inconsistent state due to data races. For arrays HogwildArray should be preferred.