pub struct Hogwild<T>(_);
Hogwild for arbitrary data types.
Hogwild subverts Rust's type system by allowing concurrent modification
of values. This should only be used for data types that cannot end up in
an inconsistent state due to data races. For arrays HogwildArray should
be preferred.
Performs copy-assignment from source. Read more
Returns the "default value" for a type. Read more
The resulting type after dereferencing.
Mutably dereferences the value.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Mutably borrows from an owned value. Read more